==> JabberGuestSDK-iOS-10.0.2.362.zip: JabberGuestSDK-iOS-10.0.2.362/docs/api/annotated.js <==
var annotated =
[
    [ "CJGuestAudioStatistics", "class_c_j_guest_audio_statistics.html", null ],
    [ "CJGuestCall", "class_c_j_guest_call.html", "class_c_j_guest_call" ],
    [ "CJGuestCallBarView", "class_c_j_guest_call_bar_view.html", "class_c_j_guest_call_bar_view" ],
    [ "<CJGuestCallBarViewDelegate>", "protocol_c_j_guest_call_bar_view_delegate-p.html", "protocol_c_j_guest_call_bar_view_delegate-p" ],
    [ "CJGuestCallKeypadView", "class_c_j_guest_call_keypad_view.html", "class_c_j_guest_call_keypad_view" ],
    [ "<CJGuestCallKeypadViewDelegate>", "protocol_c_j_guest_call_keypad_view_delegate-p.html", "protocol_c_j_guest_call_keypad_view_delegate-p" ],
    [ "CJGuestCallSelfView", "class_c_j_guest_call_self_view.html", "class_c_j_guest_call_self_view" ],
    [ "CJGuestCallViewController", "class_c_j_guest_call_view_controller.html", "class_c_j_guest_call_view_controller" ],
    [ "<CJGuestCallViewControllerDelegate>", "protocol_c_j_guest_call_view_controller_delegate-p.html", "protocol_c_j_guest_call_view_controller_delegate-p" ],
    [ "CJGuestCodecStatistics", "class_c_j_guest_codec_statistics.html", "class_c_j_guest_codec_statistics" ],
    [ "<CJGuestInvalidCertAlertViewDelegate>", "protocol_c_j_guest_invalid_cert_alert_view_delegate-p.html", "protocol_c_j_guest_invalid_cert_alert_view_delegate-p" ],
    [ "<CJGuestInvalidCertCallback>", "protocol_c_j_guest_invalid_cert_callback-p.html", "protocol_c_j_guest_invalid_cert_callback-p" ],
    [ "<CJGuestInvalidCertDelegate>", "protocol_c_j_guest_invalid_cert_delegate-p.html", "protocol_c_j_guest_invalid_cert_delegate-p" ],
    [ "CJGuestMediaStatistics", "class_c_j_guest_media_statistics.html", "class_c_j_guest_media_statistics" ],
    [ "CJGuestVideoLicense", "class_c_j_guest_video_license.html", "class_c_j_guest_video_license" ],
    [ "CJGuestVideoStatistics", "class_c_j_guest_video_statistics.html", "class_c_j_guest_video_statistics" ]
];

==> JabberGuestSDK-iOS-10.6.1.837.zip: JabberGuestSDK-iOS-10.6.1.837/docs/api/annotated.js <==
var annotated =
[
    [ "CJGuestAudioStatistics", "class_c_j_guest_audio_statistics.html", null ],
    [ "CJGuestCall", "class_c_j_guest_call.html", "class_c_j_guest_call" ],
    [ "CJGuestCallBarView", "class_c_j_guest_call_bar_view.html", "class_c_j_guest_call_bar_view" ],
    [ "<CJGuestCallBarViewDelegate>", "protocol_c_j_guest_call_bar_view_delegate-p.html", "protocol_c_j_guest_call_bar_view_delegate-p" ],
    [ "CJGuestCallKeypadView", "class_c_j_guest_call_keypad_view.html", "class_c_j_guest_call_keypad_view" ],
    [ "<CJGuestCallKeypadViewDelegate>", "protocol_c_j_guest_call_keypad_view_delegate-p.html", "protocol_c_j_guest_call_keypad_view_delegate-p" ],
    [ "CJGuestCallSelfView", "class_c_j_guest_call_self_view.html", "class_c_j_guest_call_self_view" ],
    [ "CJGuestCallViewController", "class_c_j_guest_call_view_controller.html", "class_c_j_guest_call_view_controller" ],
    [ "<CJGuestCallViewControllerDelegate>", "protocol_c_j_guest_call_view_controller_delegate-p.html", "protocol_c_j_guest_call_view_controller_delegate-p" ],
    [ "CJGuestCodecStatistics", "class_c_j_guest_codec_statistics.html", "class_c_j_guest_codec_statistics" ],
    [ "<CJGuestInvalidCertAlertViewDelegate>", "protocol_c_j_guest_invalid_cert_alert_view_delegate-p.html", "protocol_c_j_guest_invalid_cert_alert_view_delegate-p" ],
    [ "<CJGuestInvalidCertCallback>", "protocol_c_j_guest_invalid_cert_callback-p.html", "protocol_c_j_guest_invalid_cert_callback-p" ],
    [ "<CJGuestInvalidCertDelegate>", "protocol_c_j_guest_invalid_cert_delegate-p.html", "protocol_c_j_guest_invalid_cert_delegate-p" ],
    [ "CJGuestMediaStatistics", "class_c_j_guest_media_statistics.html", "class_c_j_guest_media_statistics" ],
    [ "CJGuestVideoLicense", "class_c_j_guest_video_license.html", "class_c_j_guest_video_license" ],
    [ "CJGuestVideoStatistics", "interface_c_j_guest_video_statistics.html", "interface_c_j_guest_video_statistics" ]
];
